@@ -127,9 +127,9 @@ class Pipeline:
             overwriting existing files.
         exceptions_to_catch
             Tuple of exception types to catch. An exception of one of
-            these types will be logged with logging level ERROR and
-            added to the run report, but the pipeline will continue to
-            execute.
+            these types will be added to the run report, but the
+            pipeline will continue to execute. All exceptions will be
+            logged whether they are caught or not.
 
         Note
         ----
@@ -226,7 +226,10 @@ class Pipeline:
                 self._run_pipeline_func(inpath, self._log_dict[inpath]['outpath'])
             except exceptions_to_catch as e:
                 self._log_dict[inpath]['error'] = repr(e)
-                logging.error(f'{type(e)} exception on {inpath}: {e}')
+                logging.error(f'Exception caught on {inpath}: {repr(e)}')
+            except Exception as e:
+                logging.error(f'Exception not caught on {inpath}: {repr(e)}')
+                raise
             finally:
                 self._log_dict[inpath]['time_finished'] = datetime.now()
 
